<?php defined("SYSPATH") or die("No direct script access.");
/**
 * Gallery - a web based photo album viewer and editor
 * Copyright (C) 2000-2012 Bharat Mediratta
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
 */
class Tag_by_group_Controller extends Controller {
  function dialog($album_id) {
    $album = ORM::factory("item", $album_id);
    access::required("view", $album);

    if (!tag_by_group::can_edit_tags()) {
      // The user can't edit; perhaps they just logged out?
      url::redirect($album->abs_url());
    }

    $v = new Theme_View("page.html", "collection", "tag_by_group");
    $v->content = new View("tag_by_group_dialog.html");
    $v->content->album = $album;
      $v->content->tags = array();
      foreach ($album->viewable()->children() as $child) {
        $item = ORM::factory("item", $child->id);
        $tag_names = array();
        foreach (tag::item_tags($item) as $tag) {
          $tag_names[] = $tag->name;
        }
        $v->content->tags[$child->id] = implode(", ", $tag_names);
    }
    print $v;
  }

  function save($album_id) {
    access::verify_csrf();
    $album = ORM::factory("item", $album_id);
    access::required("view", $album);

    if (Input::instance()->post("save")) {
      $titles = Input::instance()->post("title");
      $tags = Input::instance()->post("tags");
      $enable_tags = module::is_active("tag");
      foreach (array_keys($titles) as $id) {
        $item = ORM::factory("item", $id);
        if ($item->loaded() && access::can("view", $item)) {
          $item->title = $titles[$id];
          $item->save();
          if ($enable_tags) {
            tag::clear_all($item);
            foreach (explode(",", $tags[$id]) as $tag_name) {
              if ($tag_name) {
                tag::add($item, trim($tag_name));
              }
            }
            tag::compact();
          }
        }
      }
      message::success(t("Captions saved"));
    }
    url::redirect($album->abs_url());
  }
  public function tags_for($id) {
    $item = ORM::factory("item", $id);
    access::required("view", $item);
    $view = new View("tag_by_group_tags_for.html");
    $view->tags = tag::item_tags($item);
    print $view;
  }
  public function create($item_id) {
    $item = ORM::factory("item", $item_id);

    $form = tag::get_add_form($item);
    if ($form->validate()) {
      foreach (explode(",", $form->add_tag->inputs["name"]->value) as $tag_name) {
        $tag_name = trim($tag_name);
        if ($tag_name) {
          $tag = tag::add($item, $tag_name);
        }
      }

      json::reply(array("result" => "success", "cloud" => (string)tag::cloud(30)));
    } else {
      json::reply(array("result" => "error", "html" => (string)$form));
    }
  }
}
